Index: src/core/SkMaskGamma.h |
diff --git a/src/core/SkMaskGamma.h b/src/core/SkMaskGamma.h |
index be5d034c81c7ca8c6962d705dbac89867557b976..16ea47b1b01528f8682899a526a6796f33c0f9c1 100644 |
--- a/src/core/SkMaskGamma.h |
+++ b/src/core/SkMaskGamma.h |
@@ -168,7 +168,7 @@ private: |
* convert a linear alpha value for a given channel to a gamma correcting alpha |
* value for that channel. This class is immutable. |
* |
* If fR, fG, or fB is NULL, all of them will be. This indicates that no mask |
* pre blend should be applied. SkTMaskPreBlend::isApplicable() is provided as |
* a convenience function to test for the absence of this case. |
*/ |
@@ -182,7 +182,7 @@ private: |
friend class SkTMaskGamma<R_LUM_BITS, G_LUM_BITS, B_LUM_BITS>; |
public: |
/** Creates a non applicable SkTMaskPreBlend. */ |
- SkTMaskPreBlend() : fParent(), fR(NULL), fG(NULL), fB(NULL) { } |
+ SkTMaskPreBlend() : fParent(), fR(nullptr), fG(nullptr), fB(nullptr) { } |
/** |
* This copy contructor exists for correctness, but should never be called |
@@ -193,7 +193,7 @@ public: |
~SkTMaskPreBlend() { } |
/** True if this PreBlend should be applied. When false, fR, fG, and fB are NULL. */ |
bool isApplicable() const { return SkToBool(this->fG); } |
const uint8_t* fR; |
@@ -168,7 +168,7 @@ private: |
* value for that channel. This class is immutable. |
* |
- * If fR, fG, or fB is NULL, all of them will be. This indicates that no mask |
+ * If fR, fG, or fB is nullptr, all of them will be. This indicates that no mask |
* pre blend should be applied. SkTMaskPreBlend::isApplicable() is provided as |
* a convenience function to test for the absence of this case. |
@@ -193,7 +193,7 @@ public: |
~SkTMaskPreBlend() { } |
- /** True if this PreBlend should be applied. When false, fR, fG, and fB are NULL. */ |
+ /** True if this PreBlend should be applied. When false, fR, fG, and fB are nullptr. */ |
bool isApplicable() const { return SkToBool(this->fG); } |
const uint8_t* fR; |